@@ -1,3 +1,4 @@
+from django.contrib.auth.models import User
 from django.db import models
 
 
@@ -15,6 +16,15 @@ class AbstractCreatedUpdatedModel(models.Model):
         abstract = True
 
 
+class AbstractSsoUser(AbstractCreatedUpdatedModel, models.Model):
+    sso_uuid = models.CharField(max_length=100, db_index=True)
+    list_apps = models.JSONField()
+    user = models.OneToOneField(User, related_name="sso_user", on_delete=models.CASCADE)
+
+    class Meta:
+        abstract = True
+
+
 class Reference(AbstractCreatedUpdatedModel):
     code = models.CharField(max_length=20, primary_key=True)
     label = models.CharField(max_length=100)
