@@ -1,18 +1,20 @@
 import json
 
 from django.conf import settings
+from django.test.client import encode_multipart, BOUNDARY, MULTIPART_CONTENT
 
 from rest_framework import status as drf_status
 from rest_framework.test import APIClient
 
 from rest_framework_api_key.models import APIKey
-from rest_framework_simplejwt.tokens import RefreshToken
 from rest_framework.authtoken.models import Token
 
 from w import Debug
 from w.django.tests.django_testcase import DjangoTestCase
 from w.django.tests.factories.auth_factories import UserFactory
 from w.django.utils import reverse
+from w.drf.sso.sso_auth_backend import SsoAuthTestBackend
+from w.tests.helpers import date_test_helper
 
 
 class ApiTestCase(DjangoTestCase):
@@ -53,18 +55,28 @@ class ApiTestCase(DjangoTestCase):
 
     @staticmethod
     def _get_jwt_access_token(user):
+        from rest_framework_simplejwt.tokens import RefreshToken
+
         jwt_token = RefreshToken.for_user(user)
         return str(jwt_token.access_token)
 
-    @staticmethod
-    def _get_token(user):
+    @classmethod
+    def _get_token(cls, user):
         if hasattr(settings, "SIMPLE_JWT"):
-            jwt_token = RefreshToken.for_user(user)
-            return str(jwt_token.access_token)
+            return cls._get_jwt_access_token(user)
         token, created = Token.objects.get_or_create(user=user)
         return token
 
+    def _get_sso_token_header(self, user=None):
+        if user is None:
+            user = self._get_user()
+        SsoAuthTestBackend.set_user(user)
+        return "Bearer pytest-valid-token"
+
     def _get_token_header(self, user):
+        if hasattr(settings, "SSO"):
+            return self._get_sso_token_header(user)
+
         header_token_keyword = "Bearer" if hasattr(settings, "SIMPLE_JWT") else "Token"
         if user:
             token = self._get_token(user)
@@ -87,39 +99,55 @@ class ApiTestCase(DjangoTestCase):
             )
         params[API_KEY_CUSTOM_HEADER] = self.default_api_key
 
-    def set_client_params(self, params, auth_by_token=True, user=None):
-        if auth_by_token:
-            params["HTTP_AUTHORIZATION"] = self._get_token_header(user)
+    def set_client_params(self, params, **options):
+        """
+        Set client params with the provided supported options (if any) and the API
+        key header.
+
+        Args:
+            params (Dict): params to set
+            options (Kwargs): options to set params with.
+                              supported options are : "auth_by_token", "user" and
+                              "content_type"
+        """
+        if (
+            "auth_by_token" in options
+            and options["auth_by_token"]
+            and "user" in options
+        ):
+            params["HTTP_AUTHORIZATION"] = self._get_token_header(options["user"])
+
+        if "content_type" in options:
+            params["content_type"] = options["content_type"]
 
         self._add_api_key_header(params)
 
-    def _client_method(self, method, url, data=None, auth_by_token=True, user=None):
+    def _client_method(self, method, url, data=None, **options):
+        # Set default values for auth_by_token and user if no value provided
+        if "auth_by_token" not in options:
+            options["auth_by_token"] = True
+        if "user" not in options:
+            options["user"] = None
         params = {"path": url, "data": data}
-        self.set_client_params(params, auth_by_token, user)
+        self.set_client_params(params, **options)
+        if "headers" in options:
+            params = {**params, **options["headers"]}
         return getattr(self.client, method)(**params)
 
-    def client_get(self, url, auth_by_token=True, user=None):
-        return self._client_method("get", url, auth_by_token=auth_by_token, user=user)
+    def client_get(self, url, **options):
+        return self._client_method("get", url, **options)
 
-    def client_post(self, url, data=None, auth_by_token=True, user=None):
-        return self._client_method(
-            "post", url, data=data, auth_by_token=auth_by_token, user=user
-        )
+    def client_post(self, url, data=None, **options):
+        return self._client_method("post", url, data=data, **options)
 
-    def client_put(self, url, data=None, auth_by_token=True, user=None):
-        return self._client_method(
-            "put", url, data=data, auth_by_token=auth_by_token, user=user
-        )
+    def client_put(self, url, data=None, **options):
+        return self._client_method("put", url, data=data, **options)
 
-    def client_delete(self, url, data=None, auth_by_token=True, user=None):
-        return self._client_method(
-            "delete", url, data=data, auth_by_token=auth_by_token, user=user
-        )
+    def client_delete(self, url, data=None, **options):
+        return self._client_method("delete", url, data=data, **options)
 
-    def client_patch(self, url, data=None, auth_by_token=True, user=None):
-        return self._client_method(
-            "patch", url, data=data, auth_by_token=auth_by_token, user=user
-        )
+    def client_patch(self, url, data=None, **options):
+        return self._client_method("patch", url, data=data, **options)
 
     def _assert_no_registered_user_return_401(self, method, urlconf, url_params):
         response = getattr(self.client, method)(reverse(urlconf, kwargs=url_params))
@@ -271,3 +299,57 @@ class ApiTestCase(DjangoTestCase):
     def save_response_as_cypress_fixtures(cls, fixture_path, response):
         """ Save response content into cypress fixture repo """
         return cls.save_as_cypress_fixtures(fixture_path, json.loads(response.content))
+
+    def client_post_multipart_content(self, url, data):
+        """
+        Post multipart content.
+
+        Args:
+            url (str): url for the post request
+            data (dict): data to encode as multipart content
+        """
+        data = encode_multipart(BOUNDARY, {**data})
+        return self.client_post(url, data=data, content_type=MULTIPART_CONTENT)
+
+    def client_post_upload(self, url, full_path, data):
+        """
+        Post operation to make file upload.
+        Today date is mocked to "2020-02-15 12:34:56".
+
+        Args:
+            url (str): url for the post request
+            full_path (str): full path of the file to upload
+            data (dict): additional data to send in the post request
+
+        Returns:
+            response
+        """
+        with date_test_helper.today_is("2020-02-15 12:34:56"):
+            with open(full_path, "rb") as f:
+                data["file"] = f
+                return self.client_post_multipart_content(url, data)
+
+    def assert_post_upload_response(self, response, expected_full_path, **options):
+        """
+        Assert upload response and check file existence.
+
+        Args:
+            url (str): url for the post request
+            expected_full_path(str): expected full path of the uploaded file
+            options(Kwargs): supported options are :
+                             "status"(int) : expected status code of the response,
+                             default is HTTP_201_CREATED
+                             "fixture"(str): the cypress fixture to generate
+        """
+        status = (
+            options["status"] if "status" in options else drf_status.HTTP_201_CREATED
+        )
+        self.assert_rest_response(response, status=status)
+
+        if status == drf_status.HTTP_201_CREATED:
+            self.assert_file_exists(expected_full_path)
+        else:
+            self.assert_file_not_exists(expected_full_path)
+
+        if "fixture" in options and options["fixture"] is not None:
+            self.save_response_as_cypress_fixtures(options["fixture"], response)
