@@ -114,6 +114,8 @@ class ViewSet(viewsets.ViewSet):
             raise RuntimeError(f"You need to define '{serializer_key}' serializer")
         serializer_class = self.get_serializer_class(serializer_key)
         serializer = serializer_class(data=self.request.data)
+        if self.request.query_params and not self.request.data:
+            serializer = serializer_class(data=self.request.query_params)
         serializer.is_valid(raise_exception=True)
         return serializer.validated_data
 
