@@ -96,3 +96,11 @@ class AccessForbiddenError(WError):
 
     def __init__(self, message=None, params=None) -> None:
         super().__init__(message, params)
+
+
+class BadRequestError(WError):
+    """
+    Raise on an apparent client (e.g., malformed request syntax, size too large, ...)
+    """
+
+    message = "Bad Request"
