@@ -5,6 +5,7 @@ from openpyxl.utils.exceptions import InvalidFileException
 
 from w.services.abstract_service import AbstractService
 from w.services.technical.filesystem_service import FilesystemService
+from w.exceptions import ValidationError
 
 
 class ExcelService(AbstractService):
@@ -79,14 +80,19 @@ class ExcelService(AbstractService):
         sheet = wb[sheet_name] if sheet_name is not None else wb.active
 
         rows = sheet.iter_rows()
-        headers = [c.value.strip() for c in next(rows)]
-        required_headers = list(mapping_columns.keys())
-        if required_headers != headers:
-            raise RuntimeError(
-                f"incorrect or missing header, expected '{', '.join(required_headers)}'"
-                f" got '{', '.join(headers)}'"
-            )
+        headers = [c.value.strip() if c.value else None for c in next(rows)]
+        for i, required_header in enumerate(mapping_columns.keys()):
+            if required_header != headers[i]:
+                raise ValidationError(
+                    f"incorrect or missing header, "
+                    f"expected '{';'.join(list(mapping_columns.keys()))}' "
+                    f"got '{';'.join(headers)}'"
+                )
         return [
-            {mapping_columns[headers[i]]: cell.value for i, cell in enumerate(row)}
+            {
+                mapping_columns[headers[i]]: cell.value
+                for i, cell in enumerate(row)
+                if headers[i] in mapping_columns
+            }
             for row in rows
         ]
