@@ -3,6 +3,7 @@ from openpyxl import Workbook
 
 from w.services.technical.excel_service import ExcelService
 from w.tests.mixins.testcase_mixin import TestCaseMixin
+from w.exceptions import ValidationError
 
 
 class TestExcelService(TestCaseMixin):
@@ -74,21 +75,27 @@ class TestExcelService(TestCaseMixin):
         with pytest.raises(RuntimeError, match=match):
             ExcelService.load(filename, self.mapping)
 
-    def test_load_with_invalid_header_raise_runtime_error(self):
-        """ Ensure method raise runtime error if header is false """
+    def test_load_with_invalid_header_raise_validation_error(self):
+        """ Ensure method raise exceptions validation error if header is false """
         mapping = self.mapping.copy()
         mapping["colWrong"] = mapping.pop("header3")
-        match = (
-            "incorrect or missing header, expected 'header1, header2, colWrong'"
-            " got 'header1, header2, header3'"
-        )
-        with pytest.raises(RuntimeError, match=match):
+        match = "Unprocessable Entity"
+        with pytest.raises(ValidationError, match=match):
             ExcelService.load(self.filename, mapping)
 
     def test_load_with_success_return_list(self):
         """ Ensure method succeed """
         self.assert_equals_resultset(ExcelService.load(self.filename, self.mapping))
 
+    def test_load_with_empty_col_success_return_list(self):
+        """ Ensure method succeed even with an empty column """
+        self.assert_equals_resultset(
+            ExcelService.load(
+                self.get_datasets_dir("excel/Excel2010_with_empty_col.xlsx"),
+                self.mapping,
+            )
+        )
+
     def test_load_with_specific_bad_sheet_name_raise_runtime_error(self):
         """ Ensure method raise runtime error if sheet name is bad """
         match = "bad_sheet_name is not a valid sheet name"
